%% INFORMATION
% This script calculates the extreme values from wave statistics

%% PARAMETERS

% Input
neq = 11;                       % number of equations
m = 0.1;                        % bottom slope
g=9.81;                         % acceleration of gravity
sp =100;                        % number of sampling points
RP = [1 10 100 1000 10000];     % return periods
Axis = [0 35 0 35];             % axis contour line plots
x = Axis(1):0.1:Axis(2);        % x-values in plot
model_char = ...
    [1 2 2 1 1 2 2 1 2 3 4];    % type of runup model
                                % 1:a=0 2:c=1 3:Po1 4:Po2
% Declaration
Re = zeros(1,length(RP));       % handle for contour line plots
R2 = zeros(1,sp);               % R2
T_max = zeros(neq,length(RP));  % extreme value wave period
H_max = zeros(neq,length(RP));  % extreme value Hs
R2_max = zeros(neq,length(RP)); % extreme value R2
xi_max = zeros(neq,length(RP)); % extreme value surf parameter
R2sort_compWave=struct([]);     % R2 sorted by value

% Strings for plots and saving results
distr = {'MGAU05','NORA10', 'BGGS07_1', 'BGGS07_2','BGGS07_3','BGGS07_4'...
    , 'BGGS07_5','MBG90_1','MBG90_2','MBG90_3'};
model = {'Bl1','Bl2','Bld','Sc','Pe','Ho','Vo','M1','M2','Po1','Po2'};
model_name = {'Bl1','Bl2','Bld','Sc','Pe','Ho','Vo','At1','At2','Po1','Po2'};
color = {'[0 0.4470 0.7410]','[0.8500 0.3250 0.0980]'...
    ,'[0.9290 0.6940 0.1250]','[0.4940 0.1840 0.5560]'...
    ,'[0.4660 0.6740 0.1880]'};

%Parameters for marginal distirbution of Hs
s = [0.801 1.690 3.104 2.848 2.939 2.857 2.420 1.410 1.910 1.500];
r = [1.531 1.160 1.357 1.419 1.240 1.449 1.169 1.120 1.270 1.150];
t = [2.713 0.760 0.906 1.021 0.896 0.838 1.258 0.987 0.532 0.679];
k = [0.371^0.5 0 0 0 0 0 0 0 0 0];

%Parameters for conditional distribuiton of Tp given Hs
marginal = [3 1 2 2 2 2 2 4 4 4];
c_hat = [1 1 1.28 1.28 1.28 1.28 1.28 1.28 1.28 1.28];
a1=[1.780 0.74 1.350 1.365 0.790 0.835 1.952 1.240 1.090 0.933];
a2=[0.288 1.20 0.366 0.375 0.805 1.139 0.168 0.337 0.479 0.578];
a3=[0.474 0.21 0.392 0.453 0.292 0.119 0.499 0.538 0.417 0.395];
b1=[0.001 0.001 0.020 0.033 0.055 0.140 0.070 0.0728 0.0407 0.0550];
b2=[0.097 0.113 0.165 0.285 0.195 0.030 0.066 0.383 0.221 0.336];
b3=[-0.255 -0.275 -0.166 -0.752 -0.269 -0.958 -0.081 -0.665 -0.289 -0.585];

%Parameters for general equation 1
a=[0 0.39 0.21 0 0 0.2 0.58*m 0 0.16];
b=[1.165 0.795 -0.44 -0.1 4*m^(0.3) 0.83 0.53 0.99 0.92];
c=[0.77 1 1 2.21 1 1 1 1 1];
d=[0 0 0 0 0 0 0.45 0 0];

%Parameters for general equation 2
C = [0 0 0 0 0 0 0 0 0 0.49/1.28 0.33];


%% CALCULATIONS
for nd = 1:10       %distributions
    close all;
    for ieq =1:neq      %runup model
        for rp = 1:length(RP)   %return period
            %% Contour lines
            
            %Creating values for imaginary plane
            q = 1/(2920*RP(rp));
            beta = -norminv(q,0,1);
            theta = linspace(0,2*pi,sp);
            u1 = beta*cos(theta);
            u2 = beta*sin(theta);
            
            %Transforming back to physical plane
            F = normcdf(u1,0,1);
            
            if marginal(nd) == 1        %OHG16
                H = t(nd)+s(nd)*(-log(1-F)).^(1/r(nd));
                meanT = a1(nd)+a2(nd)*H.^a3(nd);
                stdT = sqrt(b1(nd)+b2(nd)*exp(b3(nd)*H));
                T = exp(stdT.*u2+meanT);
                
            elseif marginal(nd) == 2    %BGGS07
                H = t(nd)+s(nd)*(-log(1-F)).^(1/r(nd));
                meanT = a1(nd)+a2(nd)*H.^(a3(nd));
                stdT = b1(nd)+b2(nd)*H.^(b3(nd));
                T = exp(stdT.*u2+meanT);
                
            elseif marginal(nd) == 3    %MGAU05
                H = t(nd)*(-log(1-F)).^(1/r(nd));   % Hs > 3.25m
                for j=1:sp
                    if H(j) <= 3.25                 % Hs<= 3.25m
                        H(j) = exp(s(nd)+u1(j)*k(nd));
                    end
                end
                meanT = a1(nd)+a2(nd)*H.^a3(nd);
                stdT = sqrt(b1(nd)+b2(nd)*exp(b3(nd)*H));
                T = exp(stdT.*u2+meanT);
            else                        % MBG90
                H = t(nd)+s(nd)*(-log(1-F)).^(1/r(nd));
                meanT = a1(nd)+a2(nd)*H.^a3(nd);
                stdT = b1(nd)+b2(nd)*exp(b3(nd)*H);
                T = exp(stdT.*u2+meanT);
            end

            %% Plotting contour lines
            
            figI = figure(nd*20+ieq);
            Re(rp) = plot(T,H,'LineWidth',1.5,'Color',color{rp});
            hold on
            if nd == 1 || nd == 2
                xlabel('T_P [s]')
            else
                xlabel('T_Z [s]')
            end
            ylabel('H_S [m]')
            set(gca,'Fontsize',22, 'Fontname','Times New Roman')
            axis(Axis)
            
            %%   Maximum values for runup along contour lines
            
            for j = 1:sp
                if model_char(ieq) == 1         %a=0
                    R2(j) = b(ieq)*(m*c_hat(nd))^c(ieq)*(g/(2*pi))^(c(ieq)/2)...
                        *H(j)^(1-c(ieq)/2)*T(j)^c(ieq)+d(ieq);
                elseif model_char(ieq) == 2     %c=1
                    R2(j) = a(ieq)*H(j)+b(ieq)*m*c_hat(nd)...
                        *sqrt(g/(2*pi)*H(j))*T(j)+d(ieq);
                else                            %Po
                    R2(j) = C(ieq)*m^.5*c_hat(nd)*T(j)*H(j);
                end
            end
            
            if ieq == 3 || ieq == 4
                maxd=find(R2==min(R2));
            else
                maxd=find(R2==max(R2));
            end
            
            T_max(ieq,rp) = T(maxd); %Tp or Tz
            H_max(ieq,rp) = H(maxd);
            R2_max(ieq,rp) = R2(maxd);
            xi_max(ieq,rp) = m*sqrt(g/(2*pi))*c_hat(nd)*...
                T_max(ieq,rp)/sqrt(H_max(ieq,rp));
            
            %% Plotting runup models for maximum runup
            
            x = Axis(1):0.1:Axis(2);
            y = Axis(3):0.1:Axis(4);
            
            if model_char(ieq) == 1             %a=0
                H1 = ((R2(maxd)-d(ieq))./(b(ieq)*(m*c_hat(nd))^c(ieq)...
                    *(g/(2*pi))^(c(ieq)/2).*x.^c(ieq))).^(2/(2-c(ieq)));
                
                figure(nd*20+ieq);
                plot(x,H1,'--','Color',color{rp},'linewidth',1.5);
                

            elseif model_char(ieq) == 2         %c=1
                T1 = (R2(maxd)-a(ieq).*y-d(ieq))./...
                    (b(ieq)*m*c_hat(nd)*sqrt(g/(2*pi)).*sqrt(y));
                
                figure(nd*20+ieq);
                plot(T1,y,'--','Color',color{rp},'linewidth',1.5);
                              
            else                                %Po
                H1 = R2(maxd)/(C(ieq)*m^.5*c_hat(nd))./x;
                
                figure(nd*20+ieq);
                plot(x,H1,'--','Color',color{rp},'linewidth',1.5);
                
            end
            
            
        end
        
        legend(Re,'1 year','10 year','100 year','1000 year','10 000 year',...
            'Location', 'NE')
        hold off
        
        
        %% Write extreme values to file for tables in report
        
        FileName = ['ExtremeValues_' distr{nd} '_' model{ieq} '.txt'];
        FilePath = ...
            '/Users/tonjesunde/Documents/MATLAB/Masteroppgave/Tables_ExtremeValues';
        
        fid = fopen(fullfile(FilePath,FileName),'w');
        if ieq == 3 || ieq == 4
            for rp = 1:length(RP)
                fprintf(fid,'%-8d & %-10.1f & %-10.1f & %-10.2f & %-10.3f \\\\ \n'...
                    ,RP(rp),H_max(ieq,rp),T_max(ieq,rp),xi_max(ieq,rp),R2_max(ieq,rp));
            end
        else
            for rp = 1:length(RP)
                fprintf(fid,'%-8d & %-10.1f & %-10.1f & %-10.2f & %-10.1f \\\\ \n'...
                    ,RP(rp),H_max(ieq,rp),T_max(ieq,rp),xi_max(ieq,rp),R2_max(ieq,rp));
            end
        end
        fclose(fid);    
        
    end
    
    Model = (1:neq).';
    R2dim = R2_max./H_max;
    R2tab = [Model R2dim(:,1) R2dim(:,2) R2dim(:,3) R2dim(:,4) R2dim(:,5)];
    R2sort = sortrows(R2tab,2);
    
    FileName = ['ExtremeValues_' distr{nd} '.txt'];
    FilePath = ...
        '/Users/tonjesunde/Documents/MATLAB/Masteroppgave/Tables_Extreme_dimless';
    
    fid = fopen(fullfile(FilePath,FileName),'w');
    for ieq = 1:neq
        if ieq == 1 || ieq == 2
            fprintf(fid,'%-5s & %-5.3f & %-5.3f & %-5.3f & %-5.3f & %-5.3f \\\\ \n'...
                ,model_name{R2sort(ieq)}, R2sort(ieq,2), R2sort(ieq,3),...
                R2sort(ieq,4), R2sort(ieq,5), R2sort(ieq,6));
        else
            fprintf(fid,'%-5s & %-5.2f & %-5.2f & %-5.2f & %-5.2f & %-5.2f \\\\ \n'...
                ,model_name{R2sort(ieq)}, R2sort(ieq,2), R2sort(ieq,3),...
                R2sort(ieq,4), R2sort(ieq,5), R2sort(ieq,6));
        end
    end
    fclose(fid);

    R2sort_compWave(nd).Distribution = distr(nd);
    R2sort_compWave(nd).R2sortWave = R2sort;
    
end