close all
%% INFORMATION
% This script calculates the extreme values from wind statistics

%% PARAMETERS

% Input
alpha_hat=0.0081;                       % Phillips constant
g=9.81;                                 % Acceleration of gravity
neq = 11;                               % number of equations
nm=7;                                   % number of slopes in calculation
m = 0.1;                                % bottom slope
RP = [1 10 100 1000 10000];             % return periods
K=4*m^(0.3);

% Declaration
U_max = zeros(1,length(RP));
Hs_max = zeros(1,length(RP));
Tp_max = zeros(1,length(RP));
Tz_max = zeros(1,length(RP));
R2_max = zeros(neq,length(RP));
xi_max = zeros(1,length(RP));

% Strings for plots and saving results
model = {'Bl1','Bl2','Bld','Sc','Pe','Ho','Vo','At1','At2','Po1','Po2'};
period = {'1', '10', '100', '1000', '10000'};
distr = {'JMH02','MR15_1040','MR15_2060','BG15'};
model_char = [1 1 1 1 1 1 1 1 1 2 3];


%% Parameters equations

%Parameters for general equation 1
a=[0 0.39 0.21 0 0 0.2 0.58*m 0 0.16];
b=[1.165 0.795 -0.44 -0.1 K 0.83 0.53 0.99 0.92];
c=[0.77 1 1 2.21 1 1 1 1 1];
d=[0 0 0 0 0 0 0.45 0 0];

for nd = 1:4 %DISTRIBUTION
    
    %% DISTRIBUTION PARAMETERS
    if nd == 1       % JMH01
        alpha=1.708;
        beta=8.426;
    elseif nd ==2    % MR15 10W40N
        alpha=2.30;
        beta=7.11;
    elseif nd ==3    % MR15 20W60N
        alpha=2.46;
        beta=10.99;
    else            % BG15
        hs=3;
        alpha=1.250+5.600*hs^(.660);
        beta=0.050+5.514*hs^(.280);
    end
    
    %% CALCULATION OF EXTREME VALUES
    
    for ieq = 1:neq  %RUNUP MODEL
        for irp = 1:length(RP) %RETURN PERIOD
            rp = RP(irp);
            if nd == 1       % JMH01
                N = 365*24*60/60*rp;
            else
                N = 365*24*60/10*rp;
            end
            U_max(irp) = beta*(log(N))^(1/alpha);
            Tp_max(irp) = 2*pi/g*U_max(irp);
            Hs_max(irp) = 2*sqrt(alpha_hat)/g*U_max(irp)^2;
            Tz_max(irp) = sqrt(2)*pi/g*U_max(irp);
            xi_max(irp) = m*sqrt(g/(2*pi)*Tp_max(irp)^2/Hs_max(irp));
            
            if model_char(ieq) == 1         %General equation abcd
                R2_max(ieq,irp) = (a(ieq)+b(ieq)*xi_max(irp)^c(ieq))...
                    *Hs_max(irp)+d(ieq);
            elseif model_char(ieq) == 2     %Po1
                R2_max(ieq,irp) = 0.49*m^.5*Tz_max(irp)*Hs_max(irp);
            elseif model_char(ieq) == 3     %Po2
                R2_max(ieq,irp) = 0.33*m^.5*Tp_max(irp)*Hs_max(irp);
            end
        end
    end
    %%  Writing results to file for tables in the report
    
    %Extreme sea state values
    FileName = ['ExtremeValuesSeastate_' distr{nd} '.txt'];
    FilePath = ...
        '/Users/tonjesunde/Documents/MATLAB/Masteroppgave/Tables_Extreme_dimless_1hour';
    
    fid = fopen(fullfile(FilePath,FileName),'w');
    for irp = 1:length(RP)
        fprintf(fid,'%-5d  & %-5.1f & %-5.1f & %-5.1f \\\\ \n',...
            RP(irp),U_max(irp),Hs_max(irp),Tp_max(irp));
    end
    fclose(fid);
    
    %Extreme runup values
    Model = (1:neq).';
    R2_max1 = R2_max(:,1)/Hs_max(1);
    R2_max10 = R2_max(:,2)/Hs_max(2);
    R2_max100 = R2_max(:,3)/Hs_max(3);
    R2_max1000 = R2_max(:,4)/Hs_max(4);
    R2_max10000 = R2_max(:,5)/Hs_max(5);
    Sep = {'&';'&';'&';'&';'&';'&';'&';'&';'&';'&';'&';};
    EndSep = {'\\';'\\';'\\';'\\';'\\';'\\'...
        ;'\\';'\\';'\\';'\\';'\\'};
    R2tab = [Model R2_max1 R2_max10 R2_max100 R2_max1000 R2_max10000];
    R2sort = sortrows(R2tab,2);
    
    FileName = ['ExtremeValuesRunup_' distr{nd} '.txt'];
    FilePath = ...
        '/Users/tonjesunde/Documents/MATLAB/Masteroppgave/Tables_Extreme_dimless_1hour';
    fid = fopen(fullfile(FilePath,FileName),'w');
    for ieq = 1:neq
        if ieq == 1 || ieq == 2
            fprintf(fid,...
                '%-5s & %-5.3f & %-5.3f & %-5.3f & %-5.3f & %-5.3f \\\\ \n'...
                ,model{R2sort(ieq)}, R2sort(ieq,2), R2sort(ieq,3),...
                R2sort(ieq,4), R2sort(ieq,5), R2sort(ieq,6));
        else
            fprintf(fid,...
                '%-5s & %-5.2f & %-5.2f & %-5.2f & %-5.2f & %-5.2f \\\\ \n'...
                ,model{R2sort(ieq)}, R2sort(ieq,2), R2sort(ieq,3),...
                R2sort(ieq,4), R2sort(ieq,5), R2sort(ieq,6));
        end
    end
    fclose(fid);
end
